@@ -8,21 +8,18 @@
  *  
  *  Dec 2005
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This software is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this software; see the file COPYING.  If not, a copy
- *  can be downloaded from http://www.gnu.org/licenses/gpl.html, or
- *  obtained by writing to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, see <https://www.gnu.org/licenses/>.
  *
  *
  *  Author: Daniel M German dmgerman at uvic doooot ca
@@ -525,7 +522,7 @@ void getROI(TrformStr * TrPtr, aPrefs * aP, PTRect * ROIRect)
     //needed here, but for now include some representative interior points as well.
     for (y = 0; y <= TrPtr->src->height; y += 1) {
         
-        x_jump = (y==0 || y==TrPtr->src->height || abs(y - TrPtr->src->height/2)<=5) ? 1 : TrPtr->src->width/2; 
+        x_jump = (y==0 || y==TrPtr->src->height || abs((int32_t)y - (int32_t)(TrPtr->src->height)/2)<=5) ? 1 : TrPtr->src->width/2; 
 
                 for (x = 0; x <= TrPtr->src->width; x += x_jump) {
                         //convert source coordinates to cartesian coordinates (i.e. origin at center of image)
@@ -698,7 +695,6 @@ int panoCreatePanorama(fullPath ptrImageFileNames[], int counterImageFiles,
     aPrefs *prefs;
     int var01;
     int var00;
-    int colourCorrection;
 
     int lines;
     fullPath *fullPathImages;
@@ -718,7 +714,7 @@ int panoCreatePanorama(fullPath ptrImageFileNames[], int counterImageFiles,
     Image image1;               //Input Image
 
     FILE *regFile;
-    char *regScript;
+    char *regScript = NULL;
     unsigned int regLen;
     unsigned int regWritten;
 
@@ -735,7 +731,6 @@ int panoCreatePanorama(fullPath ptrImageFileNames[], int counterImageFiles,
     pano_ImageMetadata metadata;
 
     /* Variables */
-    colourCorrection = 0;       // can have values of 1 2 or 3
     var00 = 0;
     var01 = 0;
 
@@ -840,13 +835,13 @@ int panoCreatePanorama(fullPath ptrImageFileNames[], int counterImageFiles,
 
 
 
-        colourCorrection = prefs->sBuf.colcorrect;
+        //int32_t colourCorrection = prefs->sBuf.colcorrect;
         // This is a strange value:
         // colourCorrection == (i & 3) + (i+1)*4;
         // where i is the number of the reference image
         
-        assert(colourCorrection >= 0
-               && colourCorrection < (counterImageFiles + 1) * 4);
+        assert(prefs->sBuf.colcorrect >= 0
+               && prefs->sBuf.colcorrect < (counterImageFiles + 1) * 4);
         if (prefs->pano.cP.radial != 0) {
             
             var00 = prefs->pano.cP.radial_params[0][2]; // what is this for, I have NO idea.
@@ -1346,7 +1341,8 @@ int panoCreatePanorama(fullPath ptrImageFileNames[], int counterImageFiles,
     // FUNCTION ENDS HERE
 
   mainError:
-    free(regScript);
+    if(regScript != NULL)
+	free(regScript);
 
     return (-1);
 }
