@@ -1,21 +1,19 @@
 /* Panorama_Tools	-	Generate, Edit and Convert Panoramic Images
    Copyright (C) 1998,1999 - Helmut Dersch  der@fh-furtwangen.de
-   
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this software; see the file COPYING.  If not, a copy
-   can be downloaded from http://www.gnu.org/licenses/gpl.html, or
-   obtained by writing to the Free Software Foundation, Inc.,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, see <https://www.gnu.org/licenses/>.
+ */
 
 /*------------------------------------------------------------
 MODIFICATIONS:
@@ -25,7 +23,7 @@ MODIFICATIONS:
                              (ie, radial a,b,c,d = 0,0,0,1 results in no change)
                              Restructured the for(k=kstart...) look into a while loop statemachine
                              Test to try to displace 2 colors at the same time (R/G, R/B, or G/B)
-    28-July-2004 R.Platt   - Test for the possible combinations of displacements, 
+    28-July-2004 R.Platt   - Test for the possible combinations of displacements,
                              and only displace color layers that have changed
 
 ------------------------------------------------------------
