@@ -3,19 +3,16 @@
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this software; see the file COPYING.  If not, a copy
-   can be downloaded from http://www.gnu.org/licenses/gpl.html, or
-   obtained by writing to the Free Software Foundation, Inc.,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, see <https://www.gnu.org/licenses/>.  */
 
 /*------------------------------------------------------------*/
 
@@ -1124,7 +1121,7 @@ int panoMetadataCopy(pano_ImageMetadata * to, pano_ImageMetadata * from)
        Copy the metadata, allocate memory as needed
      */
     int result;
-    char *temp;
+    char *temp = NULL;
 
     assert(from != NULL);
     assert(to != NULL);
@@ -1405,7 +1402,7 @@ Boolean panoReadINT32or64(file_spec fnum, int64_t  *pLongLong, Boolean bBig )
         return panoReadINT64( fnum, pLongLong );
     else
     {
-        uint32_t Long;
+        uint32_t Long=0;
         Boolean bRtn = panoReadINT32( fnum, &Long );
         *pLongLong = (int64_t)Long;
         return bRtn;
