@@ -11,6 +11,7 @@
  */
 #include "filter.h"
 #include <float.h>
+#include <math.h>
 
 extern lmfunc fcn;
 
@@ -1222,7 +1223,6 @@ double cos,cotan,qtbpj,sin,sum,tan,temp;
 static double zero = 0.0;
 static double p25 = 0.25;
 static double p5 = 0.5;
-double fabs(), sqrt();
 
 /*
 *     copy r and (q transpose)*b to preserve input and initialize s.
@@ -1416,7 +1416,6 @@ static double rdwarf = 3.834e-20;
 static double rgiant = 1.304e19;
 static double zero = 0.0;
 static double one = 1.0;
-double fabs(), sqrt();
 
 s1 = zero;
 s2 = zero;
