@@ -3,19 +3,16 @@
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this software; see the file COPYING.  If not, a copy
-   can be downloaded from http://www.gnu.org/licenses/gpl.html, or
-   obtained by writing to the Free Software Foundation, Inc.,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, see <https://www.gnu.org/licenses/>.  */
 
 /*------------------------------------------------------------*/
 
@@ -36,7 +33,7 @@
 #define abs(a) ( (a) >= 0 ? (a) : -(a) )
 #endif
 
-#ifdef _MSC_VER
+#if defined _MSC_VER && _MSC_VER<1900
 #define isnan(a) _isnan(a)
 #define isinf(a) (_fpclass(a) == _FPCLASS_NINF || _fpclass(a) == _FPCLASS_PINF)
 #endif
@@ -517,7 +514,7 @@ int tiltForward( double x_dest, double y_dest, double* x_src, double* y_src, voi
         // First step, undo the projection of the point
         z1 = (z0 * z0) /(x_dest * (-sin(phi2)/cos(phi2))  + y_dest * tan(phi) + z0);
         
-        s = z1 / z0;
+        // s = z1 / z0;
         s = z0 /(x_dest * (-sin(phi2)/cos(phi2))  + y_dest * sin(phi)/cos(phi) + z0);
         z1 = (z0* z0) /(x_dest * (-sin(phi2)/cos(phi2))  + y_dest * sin(phi)/cos(phi) + z0);
 
@@ -1117,8 +1114,10 @@ Image * setup_panini_general(struct MakeParams* pmp)
         return NULL;
 
     /* check number of precomputed param values */
-    if( ppg->precomputedCount == 7 )
-		return ppg;		// OK
+    // this check skips the pmp->distance calculation
+    // which is needed by further calculations in the stack
+    //if( ppg->precomputedCount == 7 )
+    //		return ppg;		// OK
 	
     /* default unspecified values to 0, giving 
 		stereographic compresssion (d = 1)
@@ -2248,18 +2247,29 @@ int biplane_erect		( double x_dest,double  y_dest, double* x_src, double* y_src,
 		*y_src = 0;
 		return 0;
 	}
-	if(x_dest<0)
+	if (fabs(x_dest) < mp->pn->precomputedValue[2])
 	{
-		x = x_dest + mp->pn->precomputedValue[0] * mp->distance;
-		offset = -mp->pn->precomputedValue[1];
+		// we are in the range of the corner, use cyclindrical projection
+		return pano_erect(x_dest, y_dest, x_src, y_src, &mp->distance);
 	}
 	else
 	{
-		x = x_dest - mp->pn->precomputedValue[0] * mp->distance;
-		offset = mp->pn->precomputedValue[1];
-	}
-	rect_erect(x,y_dest,x_src,y_src,&mp->distance);
-	*x_src += offset;
+		if (x_dest < 0)
+		{
+			x = x_dest + mp->pn->precomputedValue[0] * mp->distance;
+			offset = -mp->pn->precomputedValue[1];
+		}
+		else
+		{
+			x = x_dest - mp->pn->precomputedValue[0] * mp->distance;
+			offset = mp->pn->precomputedValue[1];
+		};
+		if(!rect_erect(x, y_dest, x_src, y_src, &mp->distance))
+		{
+			return 0;
+		};
+		*x_src += offset;
+	};
 	return 1;
 }
 
@@ -2273,6 +2283,11 @@ int erect_biplane		( double x_dest,double  y_dest, double* x_src, double* y_src,
 		*y_src = 0;
 		return 0;
 	}
+	if (fabs(x_dest) < mp->pn->precomputedValue[2])
+	{
+		// we are in the range of the corner, use cyclindrical projection
+		return erect_pano(x_dest, y_dest, x_src, y_src, &mp->distance);
+	}
 	if(x_dest<0)
 	{
 		x=x_dest + mp->pn->precomputedValue[1];
@@ -2283,7 +2298,10 @@ int erect_biplane		( double x_dest,double  y_dest, double* x_src, double* y_src,
 		x=x_dest - mp->pn->precomputedValue[1];
 		offset = mp->pn->precomputedValue[0]; 
 	} 
-	erect_rect(x,y_dest,x_src,y_src,&mp->distance);
+	if(!erect_rect(x,y_dest,x_src,y_src,&mp->distance))
+	{
+		return 0;
+	};
 	*x_src += offset * mp->distance;
 	return 1;
 }
@@ -2293,33 +2311,42 @@ int biplane_distance ( double width, double b, void* params )
 {
 	if(mp->pn->formatParamCount==0)
 	{
-		mp->pn->formatParamCount = 1;
+		mp->pn->formatParamCount = 2;
 		mp->pn->formatParam[0] = 45;
+		mp->pn->formatParam[1] = 0;
+	};
+	if (mp->pn->formatParamCount == 1)
+	{
+		mp->pn->formatParamCount = 2;
+		mp->pn->formatParam[1] = 0;
 	};
 	mp->pn->formatParam[0]= max( min(mp->pn->formatParam[0], 179), 1);
+	mp->pn->formatParam[1] = mp->pn->formatParam[1] > 0.1 ? 1 : 0;
 
-	mp->pn->precomputedCount = 2;
+	mp->pn->precomputedCount = 3;
 	mp->pn->precomputedValue[0] = DEG_TO_RAD(mp->pn->formatParam[0]) / 2;  // angle in rad
 	mp->distance = (double) width / (2.0 * (tan(mp->pn->precomputedValue[0])+tan(b/2.0 - mp->pn->precomputedValue[0])));
 	mp->pn->precomputedValue[1]=mp->distance*tan(mp->pn->precomputedValue[0]);  // offset
+	mp->pn->precomputedValue[2] = mp->pn->formatParam[1] * mp->pn->precomputedValue[0] * mp->distance;  // for round corners
 	return 1;
 }
 
 int triplane_erect		( double x_dest,double  y_dest, double* x_src, double* y_src, void* params )
 {
 	double x,offset;
-	if(fabs(x_dest / mp->distance)> mp->pn->precomputedValue[0] + DEG_TO_RAD(89))
+	const double x0 = x_dest / mp->distance;
+	if(fabs(x0)> mp->pn->precomputedValue[0] + DEG_TO_RAD(89))
 	{
 		*x_src = 0;
 		*y_src = 0;
 		return 0;
 	};
-	if(x_dest < -mp->pn->precomputedValue[0] / 2)
+	if(x0 < -mp->pn->precomputedValue[0] / 2)
 	{
 		x=x_dest + mp->pn->precomputedValue[0] * mp->distance;
-		offset = - mp->pn->precomputedValue[1];
+		offset = -2.0 * mp->pn->precomputedValue[1];
 	}
-	else if (x_dest < mp->pn->precomputedValue[0] / 2)
+	else if (x0 < mp->pn->precomputedValue[0] / 2)
 	{
 		x=x_dest;
 		offset=0;
@@ -2327,9 +2354,12 @@ int triplane_erect		( double x_dest,double  y_dest, double* x_src, double* y_src
 	else
 	{
 		x=x_dest - mp->pn->precomputedValue[0] * mp->distance;
-		offset = + mp->pn->precomputedValue[1];
+		offset = +2.0 * mp->pn->precomputedValue[1];
 	}
-	rect_erect(x,y_dest,x_src,y_src,&mp->distance);
+	if(!rect_erect(x,y_dest,x_src,y_src,&mp->distance))
+	{
+		return 0;
+	};
 	*x_src += offset;
 	return 1;
 }
@@ -2358,7 +2388,10 @@ int erect_triplane		( double x_dest,double  y_dest, double* x_src, double* y_src
 		x=x_dest - 2 * mp->pn->precomputedValue[1];
 		offset = + mp->pn->precomputedValue[0];
 	}
-	erect_rect(x,y_dest,x_src ,y_src,&mp->distance);
+	if(!erect_rect(x,y_dest,x_src ,y_src,&mp->distance))
+	{
+		return 0;
+	};
 	*x_src += offset * mp->distance;
 	return 1;
 }
