@@ -3,19 +3,16 @@
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this software; see the file COPYING.  If not, a copy
-   can be downloaded from http://www.gnu.org/licenses/gpl.html, or
-   obtained by writing to the Free Software Foundation, Inc.,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, see <https://www.gnu.org/licenses/>.  */
 
 /*------------------------------------------------------------*/
 
@@ -34,7 +31,7 @@
 #define PANO13_IMPEX
 #endif
 
-#include "pt_stdint.h"
+#include <stdint.h>
 #include "version.h"
 #include "panotypes.h"
 
@@ -52,6 +49,8 @@
 #if defined(_BYTE_ORDER) && (_BYTE_ORDER == _BIG_ENDIAN)
 #define PT_BIGENDIAN 1
 #endif
+#elif defined(__APPLE__)
+#include <machine/endian.h>
 #else
 #include <endian.h>
 #endif
