@@ -1,21 +1,19 @@
 /* Panoama_Tools   -   Generate, Edit and Convert Panoramic Images
    Copyright (C) 1998,1999 - Helmut Dersch  der@fh-furtwangen.de
-   
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this software; see the file COPYING.  If not, a copy
-   can be downloaded from http://www.gnu.org/licenses/gpl.html, or
-   obtained by writing to the Free Software Foundation, Inc.,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, see <https://www.gnu.org/licenses/>.
+ */
 
 /*
     Modifications by Max Lyons (maxlyons@erols.com):
@@ -458,14 +456,14 @@ int ParseScript( char* script, AlignInfo *gl )
                         case '\t': li++; break;
                         case 'i' : READ_VAR( "%d", &(gl->t[nt].nIm));   break;
                         default  : if(i<3)
-                            {
-                                li--;
-                                READ_VAR( "%d", &(gl->t[nt].vert[i]) ); 
-                                i++;
-                            }
-                        else
-                            li++;
-                            break;
+                                       {
+                                           li--;
+                                           READ_VAR( "%d", &(gl->t[nt].vert[i]) ); 
+                                           i++;
+                                       }
+                                   else
+                                       li++;
+                                   break;
                         }
                 }
             nt++;
@@ -866,7 +864,7 @@ int ParseScript( char* script, AlignInfo *gl )
 
 // Report Results 
 
-void WriteResults( char* script, fullPath *sfile,  AlignInfo *g, double ds( int i), int launch)
+void WriteResults( char* script, fullPath *sfile,  AlignInfo *g, double ds( int i) )
 {
     char        *res, **hres, *line;
     int         optHfov;         // Has hfov being optimized?
@@ -1137,7 +1135,7 @@ void WriteResults( char* script, fullPath *sfile,  AlignInfo *g, double ds( int
             }
         }
     }
-    if( WriteScript( res, sfile, launch ) != 0 )
+    if( WriteScript( res, sfile ) != 0 )
     {
         PrintError("Could not write results to scriptfile");
     }
@@ -1393,7 +1391,7 @@ int readAdjust( aPrefs *p,  fullPath* sfile, int insert, sPrefs *sP )
     }
     
     
-    if( WriteScript( script, sfile, 0 ) != 0 )      {
+    if( WriteScript( script, sfile ) != 0 )      {
         PrintError("Could not write scriptfile");
         goto fail;
     }
@@ -1534,7 +1532,7 @@ void nextLine( register char* line, char** ch )
     
     //Increased by Max Lyons (January 12, 2003) to increase size of optimizer
     //lines that can be read (previously hard-coded to 255 characters).
-    while( *c != 0 && *c != '\n' && i++<LINE_LENGTH)
+    while( *c != 0 && *c != '\n' && i++<(LINE_LENGTH-1))
         *line++ = *c++;
     *line = 0;
     *ch = c;
