@@ -3,19 +3,16 @@
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this software; see the file COPYING.  If not, a copy
-   can be downloaded from http://www.gnu.org/licenses/gpl.html, or
-   obtained by writing to the Free Software Foundation, Inc.,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, see <https://www.gnu.org/licenses/>.  */
 
 /*------------------------------------------------------------*/
 
@@ -537,16 +534,6 @@ void myfree( void** Hdl )
 }
 		
 
-// Display Scriptfile using plain text editor
-
-void showScript( fullPath* scriptFile )
-{
-		open_selection( scriptFile );
-}
-
-
-
-
 //------------------ Some Private functions ---------------------------------------------
 	
 	
@@ -1072,59 +1059,6 @@ Boolean IsAppRunning(FSSpec *myApp)
 	return (false);
 }
 
-
-#include <time.h>
-
-int LaunchAndSendScript(char* application, char* script){
-	AEAddressDesc	target;
-	OSErr			myErr;
-	AppleEvent		appleEvent,reply;
-	fullPath		theApp;
-	FInfo			finfo;
-	EventRecord				event;
-	int tt;
-
-	if( makePathToHost( &theApp ) != 0 ){
-		PrintError("Could not find host application");
-		return -1;
-	}
-	
-	strcpy((char*)theApp.name, application);
-	c2pstr((char*)theApp.name);
-
-	open_selection( &theApp );
-
-	tt = time(NULL);
-	while( time(NULL) < tt + 10  && !IsAppRunning(&theApp) )
-			WaitNextEvent ( everyEvent, &event, 100L, nil);
-	
-
-     // Create Descriptor 
-
-	FSpGetFInfo (&theApp,&finfo) ;
-    myErr = AECreateDesc( typeApplSignature, (Ptr)(&finfo.fdCreator),
-                                (Size)sizeof( finfo.fdCreator ), &target);
-	
-	if(myErr != noErr){
-		PrintError("Error creating AE descriptor");
-		return -1;
-	}
-	
-
-	if( MakeDoScriptEvent(script, &appleEvent, &target, 'dosc')){
-		PrintError("Error creating DOSC Apple Event");
-		return -1;
-	}
-
-	AESend(&appleEvent, &reply, kAENoReply+kAENeverInteract, 
-				 kAENormalPriority, kAEDefaultTimeout, nil, nil) ;
-
-	AEDisposeDesc(&appleEvent);
-	AEDisposeDesc(&reply) ;
-	
-	return 0;
-}		
-	
 unsigned char *MyCtoPStr(char *x) //added by Kekus Digital
 { 
     CopyCStringToPascal(x,x); 
