@@ -1,21 +1,19 @@
 /* Panorama_Tools	-	Generate, Edit and Convert Panoramic Images
    Copyright (C) 1998,1999 - Helmut Dersch  der@fh-furtwangen.de
-   
+
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this software; see the file COPYING.  If not, a copy
-   can be downloaded from http://www.gnu.org/licenses/gpl.html, or
-   obtained by writing to the Free Software Foundation, Inc.,
-   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   You should have received a copy of the GNU General Public License along
+   with this program; if not, see <https://www.gnu.org/licenses/>.
+ */
 
 
 /*
@@ -561,23 +559,6 @@ void 	myfree( void** Hdl )						// free Memory, use Handles
 	}
 }
 
-
-
-
-
-
-
-// Display Scriptfile using plain text editor
-
-void showScript( fullPath* scriptFile )
-{
-	char cmd[ MAX_PATH_LENGTH + 32 ];
-	snprintf( cmd, sizeof(cmd)-1, "Notepad \"%s\"", scriptFile->name );
-	WinExec( cmd , SW_SHOWNORMAL );
-}
-
-	
-
 void CenterDialog(HWND hDlg)
 {
     HWND hParent;
@@ -911,27 +892,6 @@ int IsTextFile( char* fname )
 	return FALSE;
 }
 
-int LaunchAndSendScript(char* application, char* script){
-	char *cmd;
-	
-	cmd = (char*) malloc( strlen(application) + strlen(script) + 16 );
-	
-	if( cmd == NULL )
-	{
-		PrintError("Not enough memory");
-		return -1;
-	}
-	sprintf( cmd , "%s %s", application, script );
-	if(strlen(cmd)<256){
-		WinExec( cmd , SW_SHOWNORMAL );
-		return 0;
-	}else{
-		PrintError("Command too long for WinExec");
-		free( cmd );
-		return -1;
-	}
-}		
-
 int 	StringtoFullPath	(fullPath *path, char *filename){
 	if( strlen( filename ) < 256 ){
 		strcpy( path->name, filename );
