@@ -10,21 +10,18 @@
  *
  *  Oct 2006
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This software is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this software; see the file COPYING.  If not, a copy
- *  can be downloaded from http://www.gnu.org/licenses/gpl.html, or
- *  obtained by writing to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, see <https://www.gnu.org/licenses/>.
  *
  *
  *  Author: Daniel M German dmgerman at uvic doooot ca
@@ -36,7 +33,7 @@
 
 #define PT_CROP_USAGE "PTuncrop [options] <inputFiles+>\n\n" \
     "Options:\n"                                                        \
-    "\t-p <prefix>\tPrefix for output files (defaults to " DEFAULT_PREFIX "%%4d)\n"	\
+    "\t-p <prefix>\tPrefix for output files (defaults to " DEFAULT_PREFIX ")\n"	\
     "\t-f\t\tForce processing: Overwrite output files if they exists (use with care)\n"      \
     "\t-x\t\tDelete source files (use with care)\n"\
     "\t-q\t\tQuiet run\n"\
