@@ -7,21 +7,18 @@
  *
  *  Jan 2006
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *  This software is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this software; see the file COPYING.  If not, a copy
- *  can be downloaded from http://www.gnu.org/licenses/gpl.html, or
- *  obtained by writing to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, see <https://www.gnu.org/licenses/>.
  *
  *
  *  Author: Daniel M German dmgerman at uvic doooot ca
@@ -75,7 +72,6 @@ int main(int argc,char *argv[])
     int opt;
     char *endPtr;
     fullPath *ptrInputFiles;
-    int counter;
     fullPath outputFilename;
     int filesCount;
     int base = 0;
@@ -90,7 +86,6 @@ int main(int argc,char *argv[])
     bzero(&flatteningParms, sizeof(flatteningParms));
 
     ptrInputFiles = NULL;
-    counter = 0;
 
     printf(PT_TIFF2PSD_VERSION);
 
